@@ -1,14 +1,12 @@
 from enum import Enum
 
 
-class LevelEnum(Enum):
-    INFO = "INFO"
-    WARNING = "WARNING"
-    ERROR = "ERROR"
-    CRITICAL = "CRITICAL"
-
-
 class HeaderEnum(Enum):
+    """
+    Enum class representing header constants.
+    """
+
+    ACCESS_CONTROL_ALLOW_PRIVATE_NETWORK = "Access-Control-Allow-Private-Network"
     STATUS_DESCRIPTION = "x-status-description"
     PAGINATION = "x-pagination"
     PROCESS_TIME = "x-process-time"
